@@ -23,9 +23,9 @@ const sequelizeTransactionAsyncLocalStorage = new AsyncLocalStorage();
 // eslint-disable-next-line react-hooks/rules-of-hooks
 Sequelize.useCLS({
   bind: () => {}, // compatibility with cls-hooked, not used by sequelize
-  get: (id) => sequelizeTransactionAsyncLocalStorage.getStore()?.get(id),
+  get: id => sequelizeTransactionAsyncLocalStorage.getStore()?.get(id),
   set: (id, value) => sequelizeTransactionAsyncLocalStorage.getStore()?.set(id, value),
-  run: (callback) => sequelizeTransactionAsyncLocalStorage.run(new Map(), callback),
+  run: callback => sequelizeTransactionAsyncLocalStorage.run(new Map(), callback),
 });
 
 // When a transaction is started, Sequelize wraps all calls in a `run()` call on the clsAsyncLocalStorage,
@@ -208,11 +208,11 @@ export async function initDatabase(dbOptions) {
   // of calling it to the implementing server (this allows for skipping migrations
   // in favour of calling sequelize.sync() during test mode)
   // eslint-disable-next-line require-atomic-updates
-  sequelize.migrate = async (direction) => {
+  sequelize.migrate = async direction => {
     await migrate(log, sequelize, direction);
   };
 
-  sequelize.assertUpToDate = async (options) => assertUpToDate(log, sequelize, options);
+  sequelize.assertUpToDate = async options => assertUpToDate(log, sequelize, options);
 
   // init all models
   const modelClasses = Object.values(models);
@@ -223,7 +223,7 @@ export async function initDatabase(dbOptions) {
     primaryKey: true,
   };
   log.info('registeringModels', { count: modelClasses.length });
-  modelClasses.forEach((modelClass) => {
+  modelClasses.forEach(modelClass => {
     if ('initModel' in modelClass) {
       modelClass.initModel(
         {
@@ -240,13 +240,13 @@ export async function initDatabase(dbOptions) {
     }
   });
 
-  modelClasses.forEach((modelClass) => {
+  modelClasses.forEach(modelClass => {
     if (modelClass.initRelations) {
       modelClass.initRelations(models);
     }
   });
 
-  modelClasses.forEach((modelClass) => {
+  modelClasses.forEach(modelClass => {
     if (
       modelClass.syncDirection === SYNC_DIRECTIONS.DO_NOT_SYNC &&
       modelClass.usesPublicSchema &&
