@@ -1,3 +1,8 @@
+export const GLOBAL_EXCLUDE_TABLES = [
+  // internal migration tables
+  'public.SequelizeMeta',
+];
+
 export const NON_SYNCING_TABLES = [
   'logs.debug_logs',
   'logs.fhir_writes',
@@ -6,7 +11,6 @@ export const NON_SYNCING_TABLES = [
   'public.one_time_logins',
   'public.patient_vrs_data',
   'public.refresh_tokens',
-  'public.SequelizeMeta',
   'public.signers',
   'public.sync_device_ticks',
   'public.sync_lookup_ticks',
@@ -18,8 +22,9 @@ export const NON_SYNCING_TABLES = [
 ];
 
 export const NON_LOGGED_TABLES = [
-  'logs.changes',
-  'logs.debug_logs',
+  // logs
+  'logs.*',
+
   // internal authentication tables
   'public.one_time_logins',
   'public.refresh_tokens',
